pub struct UnitsError(/* private fields */);Expand description
Wraps a raw error code returned by the units engine.
Implementations
Sourceimpl UnitsError
impl UnitsError
Sourcepub fn is_not_dimensionless(&self) -> bool
pub fn is_not_dimensionless(&self) -> bool
Returns true when the error indicates a dimensionless reduction failed.
Sourcepub fn is_invalid_unit(&self) -> bool
pub fn is_invalid_unit(&self) -> bool
Returns true when the expression was invalid (unknown/unparseable).